@@ -142,13 +142,14 @@ sparsegl <- function(
   eps = 1e-08, maxit = 3e+06) {
 
   this.call <- match.call()
-  if (!is.matrix(x) && !inherits(x, "sparseMatrix"))
-    abort("`x` must be a matrix.")
+  if (!is.matrix(x) && !inherits(x, "sparseMatrix")) {
+    cli::cli_abort("`x` must be a matrix.")
+  }
 
-  if (any(is.na(x))) abort("Missing values in `x` are not allowed!")
+  if (any(is.na(x))) cli::cli_abort("Missing values in `x` are not supported.")
 
   y <- drop(y)
-  if (!is.null(dim(y))) abort("`y` must be a vector or 1-column matrix.")
+  if (!is.null(dim(y))) cli::cli_abort("`y` must be a vector or 1-column matrix.")
   np <- dim(x)
   nobs <- as.integer(np[1])
   nvars <- as.integer(np[2])
@@ -157,8 +158,7 @@ sparsegl <- function(
   if (is.null(vnames)) vnames <- paste("V", seq(nvars), sep = "")
 
   if (length(y) != nobs) {
-    cli::cli_abort(c("`x` has {nobs} rows while `y` has {length(y)}.",
-                     "Both should be the same."))
+    cli::cli_abort("`x` has {nobs} rows while `y` has {length(y)}.")
   }
 
   #    group setup
@@ -166,37 +166,51 @@ sparsegl <- function(
     group <- 1:nvars
   } else {
     if (length(group) != nvars) {
-      cli::cli_abort(c("The length of group is {length(group)}.",
-                       "It must match the number of columns in `x`: {nvars}"))
+      cli::cli_abort(c(
+        "The length of `group` is {length(group)}.",
+        "It must match the number of columns in `x`: {nvars}"
+      ))
     }
   }
 
   bn <- as.integer(max(group))  # number of groups
   bs <- as.integer(as.numeric(table(group)))  # number of elements in each group
 
-  if (!identical(as.integer(sort(unique(group))), as.integer(1:bn)))
-    abort("Groups must be consecutively numbered 1, 2, 3, ...")
+  if (!identical(as.integer(sort(unique(group))), as.integer(1:bn))) {
+    cli::cli_abort("Groups must be consecutively numbered 1, 2, 3, ...")
+  }
 
   if (asparse > 1) {
-    abort(c("`asparse` must be less than or equal to 1",
-            i = "You may want glmnet::glmnet() instead."))}
+    cli::cli_abort(c(
+      "`asparse` must be less than or equal to 1.",
+      i = "You may want {.fn glmnet::glmnet} instead."
+    ))
+  }
 
   if (asparse < 0) {
     asparse <- 0
-    rlang::warn("asparse must be in [0,1], running ordinary group lasso.")
+    cli::cli_warn("`asparse` must be in {.val [0, 1]}, running ordinary group lasso.")
+  }
+  if (any(pf_sparse < 0)) cli::cli_abort("`pf_sparse` must be non-negative.")
+  if (any(is.infinite(pf_sparse))) {
+    cli::cli_abort(
+      "`pf_sparse` may not be infinite. Simply remove the column from `x`."
+    )
+  }
+  if (any(pf_group < 0)) cli::cli_abort("`pf_group` must be non-negative.")
+  if (any(is.infinite(pf_group))) {
+    cli::cli_abort(c(
+      "`pf_group` must be finite.",
+      i = "Simply remove the group from `x`."
+    ))
   }
-  if (any(pf_sparse < 0)) abort("`pf_sparse` must be non-negative.")
-  if (any(is.infinite(pf_sparse)))
-    abort("`pf_sparse` may not be infinite. Simply remove the column from `x`.")
-  if (any(pf_group < 0)) abort("`pf_group` must be non-negative.")
-  if (any(is.infinite(pf_group)))
-    abort("`pf_group` may not be infinite. Simply remove the group from `x`.")
   if (all(pf_sparse == 0)) {
     if (asparse > 0) {
-      abort(c("`pf_sparse` is identically 0 but `asparse` suggests",
-            "!" = "some L1 penalty is desired."))
+      cli::cli_abort(
+        "`pf_sparse` is identically 0 but `asparse` suggests some L1 penalty is desired."
+      )
     } else {
-      rlang::warn("`pf_sparse` was set to 1 since `asparse == 0`.")
+      cli::cli_warn("`pf_sparse` was set to 1 because `asparse` = {.val {0}}.")
       pf_sparse = rep(1, nvars)
     }
   }
@@ -213,12 +227,12 @@ sparsegl <- function(
   #parameter setup
   if (length(pf_group) != bn) {
     cli::cli_abort(
-      "The length of `pf_group` must be the same as the number of groups {bn}."
+      "The length of `pf_group` must be the same as the number of groups: {.val {bn}}."
     )
   }
   if (length(pf_sparse) != nvars) {
     cli::cli_abort(
-      "The length of `pf_sparse` must be equal to the number of predictors {nvars}."
+      "The length of `pf_sparse` must be equal to the number of predictors: {.val {nvars}}."
     )
   }
 
@@ -233,32 +247,34 @@ sparsegl <- function(
   #lambda setup
   nlam <- as.integer(nlambda)
   if (is.null(lambda)) {
-    if (lambda.factor >= 1) abort("`lambda.factor` must be less than 1.")
+    if (lambda.factor >= 1) {
+      cli::cli_abort("`lambda.factor` must be less than {.val {1}}.")
+    }
     flmin <- as.double(lambda.factor)
     ulam <- double(1)
   } else {
     #flmin = 1 if user define lambda
     flmin <- as.double(1)
-    if (any(lambda < 0)) abort("`lambda` must be non-negative.")
+    if (any(lambda < 0)) cli::cli_abort("`lambda` must be non-negative.")
     ulam <- as.double(rev(sort(lambda)))
     nlam <- as.integer(length(lambda))
   }
   intr <- as.integer(intercept)
 
   ### check on upper/lower bounds
-  if (any(lower_bnd > 0)) abort("`lower_bnd` must be non-positive")
-  if (any(upper_bnd < 0)) abort("`upper_bnd` must be non-negative")
+  if (any(lower_bnd > 0)) cli::cli_abort("`lower_bnd` must be non-positive.")
+  if (any(upper_bnd < 0)) cli::cli_abort("`upper_bnd` must be non-negative.")
   lower_bnd[lower_bnd == -Inf] <- -9.9e30
   upper_bnd[upper_bnd == Inf] <- 9.9e30
   if (length(lower_bnd) < bn) {
     if (length(lower_bnd) == 1) lower_bnd <- rep(lower_bnd, bn)
-    else cli::cli_abort("`lower_bnd` must be length 1 or length {bn}.")
+    else cli::cli_abort("`lower_bnd` must be length {.val {1}} or length {.val {bn}}.")
   } else {
     lower_bnd <- lower_bnd[seq_len(bn)]
   }
   if (length(upper_bnd) < bn) {
     if (length(upper_bnd) == 1) upper_bnd <- rep(upper_bnd, bn)
-    else cli::cli_abort("`upper_bnd` must be length 1 or length {bn}.")
+    else cli::cli_abort("`upper_bnd` must be length {.val {1}} or length {.val {bn}}.")
   } else {
     upper_bnd <- upper_bnd[seq_len(bn)]
   }
@@ -266,8 +282,21 @@ sparsegl <- function(
   storage.mode(lower_bnd) <- "double"
 
   # call R sub-function
-  if (is.character(family)) {
+  fam <- validate_family(family)
+  if (fam$check == "char") {
     family <- match.arg(family)
+    if (!is.null(weights)) {
+      cli::cli_warn(c(
+        "Currently, `weights` are only supported when `family` has class {.cls family}.",
+        i = "Estimating unweighted sparse group lasso. See {.fn sparsegl::sparsegl}."
+      ))
+    }
+    if (!is.null(offset)) {
+      cli::cli_warn(c(
+        "Currently, `offset` is only supported when `family` has class {.cls family}.",
+        i = "Estimating sparse group lasso without any offset. See {.fn sparsegl::sparsegl}."
+      ))
+    }
     fit <- switch(
       family,
       gaussian = sgl_ls(
@@ -279,12 +308,13 @@ sparsegl <- function(
         dfmax, pmax, nlam, flmin, ulam, eps, maxit, vnames, group, intr,
         as.double(asparse), standardize, lower_bnd, upper_bnd)
     )
-  } else {
+  }
+  if (fam$check == "fam") {
     fit <- sgl_irwls(
       bn, bs, ix, iy, nobs, nvars, x, y, pf_group, pf_sparse,
       dfmax, pmax, nlam, flmin, ulam, eps, maxit, vnames, group, intr,
       as.double(asparse), standardize, lower_bnd, upper_bnd, weights,
-      offset, family, trace_it, warm
+      offset, fam$family, trace_it, warm
     )
   }
 
