@@ -18,6 +18,6 @@ test_that("cv navigates the options properly", {
   expect_silent(cv.sparsegl(X, y, groups, family = "binomial", pred.loss = "mae"))
   expect_silent(cv.sparsegl(X, y, groups, family = "binomial", pred.loss = "deviance"))
   expect_silent(cv.sparsegl(X, y, groups, family = "binomial", pred.loss = "misclass"))
-  expect_error(cv.sparsegl(X, y, groups, family = binomial(), pred.loss = "misclass"))
+  expect_silent(cv.sparsegl(X, y, groups, family = binomial(), pred.loss = "misclass"))
 
 })
